==> splancs_2.01-3.tar.gz: splancs/data/uganda.R <==
"uganda" <- list(x = c(2310.000000, 2298.000000, 2490.000000, 2346.000000,
2011.000000, 2310.000000, 2633.000000, 2609.000000, 2550.000000,
2609.000000, 2609.000000, 2262.000000, 2203.000000, 2286.000000,
2478.000000, 2203.000000, 1784.000000, 2107.000000, 2310.000000,
2358.000000, 2370.000000, 2023.000000, 2107.000000, 2215.000000,
2059.000000, 2011.000000, 2167.000000, 2179.000000, 2083.000000,
1987.000000, 1927.000000, 1868.000000, 1891.000000, 1987.000000,
2071.000000, 2059.000000, 1951.000000, 515.000000, 2322.000000,
2502.000000, 2358.000000, 2191.000000, 2047.000000, 1951.000000,
1903.000000, 1736.000000, 2753.000000, 2478.000000, 2131.000000,
1353.000000, 1724.000000, 1903.000000, 2023.000000, 2143.000000,
2322.000000, 2430.000000, 1293.000000, 1377.000000, 1413.000000,
1532.000000, 1616.000000, 1784.000000, 1856.000000, 1975.000000,
1509.000000, 1652.000000, 1820.000000, 1497.000000, 1604.000000,
1796.000000, 2143.000000, 2143.000000, 1293.000000, 1461.000000,
1521.000000, 1664.000000, 2071.000000, 1796.000000, 1712.000000,
1616.000000, 1592.000000, 1197.000000, 1353.000000, 1365.000000,
1174.000000, 1293.000000, 1377.000000, 1401.000000, 1449.000000,
1006.000000, 1066.000000, 1102.000000, 1138.000000, 1233.000000,
1209.000000, 1030.000000, 1078.000000, 1353.000000, 1544.000000,
1736.000000, 1688.000000, 1676.000000, 1401.000000, 1042.000000,
1090.000000, 1090.000000, 1078.000000, 1126.000000, 1162.000000,
862.000000, 683.000000, 611.000000, 587.000000, 515.000000, 432.000000,
324.000000, 731.000000, 695.000000, 635.000000, 563.000000 ), y =
c(4144.000000, 4070.000000, 3967.000000, 3878.000000, 3759.000000,
3804.000000, 3922.000000, 3804.000000, 3700.000000, 3715.000000,
3626.000000, 3656.000000, 3611.000000, 3581.000000, 3537.000000,
3493.000000, 3478.000000, 3419.000000, 3404.000000, 3404.000000,
3463.000000, 3389.000000, 3315.000000, 3300.000000, 3256.000000,
3196.000000, 3226.000000, 3152.000000, 3137.000000, 3107.000000,
3107.000000, 3122.000000, 3019.000000, 3019.000000, 3004.000000,
2944.000000, 2944.000000, 974.000000, 3078.000000, 3004.000000,
2930.000000, 2826.000000, 2796.000000, 2781.000000, 2856.000000,
2856.000000, 3759.000000, 3419.000000, 3048.000000, 2767.000000,
2648.000000, 2619.000000, 2678.000000, 2678.000000, 2722.000000,
2737.000000, 2559.000000, 2589.000000, 2633.000000, 2589.000000,
2604.000000, 2544.000000, 2544.000000, 2574.000000, 2441.000000,
2470.000000, 2426.000000, 2367.000000, 2322.000000, 2307.000000,
2322.000000, 2204.000000, 2248.000000, 2204.000000, 2204.000000,
2189.000000, 1967.000000, 2011.000000, 1981.000000, 2041.000000,
2159.000000, 2219.000000, 2174.000000, 2100.000000, 2100.000000,
2026.000000, 2011.000000, 1922.000000, 1907.000000, 1937.000000,
1937.000000, 1922.000000, 1893.000000, 1848.000000, 1937.000000,
2056.000000, 2011.000000, 1848.000000, 1670.000000, 1656.000000,
1537.000000, 1478.000000, 1419.000000, 1522.000000, 1537.000000,
1581.000000, 1641.000000, 1730.000000, 1685.000000, 1641.000000,
1670.000000, 1611.000000, 1730.000000, 1700.000000, 1685.000000,
1700.000000, 1211.000000, 1093.000000, 974.000000, 1004.000000),
area=c(xl=324, xu=2753, yl=974, yu=4144), poly=cbind(x=c(396.00, 2574.00,
2574.00, 2562.00, 2526.00, 2514.00, 2346.00, 2334.00, 2322.00, 2310.00,
2298.00, 2274.00, 2250.00, 2226.00, 2215.00, 2179.00, 2155.00, 2143.00,
2143.00, 2119.00, 2119.00, 2095.00, 2095.00, 2083.00, 2071.00, 2059.00,
2047.00, 2023.00, 2023.00, 1915.00, 1915.00, 1891.00, 1891.00, 1820.00,
1820.00, 1808.00, 1808.00, 1760.00, 1760.00, 1736.00, 1700.00, 1664.00,
1652.00, 1616.00, 1604.00, 1592.00, 1592.00, 1497.00, 1497.00, 1485.00,
1485.00, 1473.00, 1389.00, 1377.00, 1377.00, 1365.00, 1365.00, 1317.00,
1329.00, 1329.00, 1341.00, 1341.00, 1317.00, 1305.00, 1281.00, 1281.00,
1269.00, 1269.00, 1257.00, 1281.00, 1281.00, 1257.00, 1257.00, 1233.00,
1221.00, 1197.00, 1197.00, 1185.00, 1185.00, 1174.00, 1150.00, 1138.00,
1138.00, 1102.00, 1102.00, 1090.00, 1090.00, 1042.00, 1030.00, 1018.00,
1006.00, 994.00, 994.00, 982.00, 970.00, 946.00, 922.00, 874.00, 874.00,
826.00, 826.00, 779.00, 755.00, 695.00, 683.00, 671.00, 527.00, 515.00,
372.00, 360.00, 348.00, 312.00, 300.00, 264.00, 264.00, 276.00, 276.00,
324.00, 384.00, 408.00, 491.00, 515.00, 527.00, 539.00, 587.00, 611.00,
635.00, 647.00, 695.00, 707.00, 707.00, 731.00, 731.00, 755.00, 755.00,
731.00, 719.00, 707.00, 695.00, 683.00, 671.00, 659.00, 659.00, 635.00,
647.00, 647.00, 635.00, 623.00, 599.00, 575.00, 551.00, 539.00, 527.00,
527.00, 515.00, 503.00, 491.00, 491.00, 468.00, 527.00, 527.00, 539.00,
551.00, 563.00, 563.00, 611.00, 659.00, 683.00, 683.00, 671.00, 671.00,
659.00, 731.00, 731.00, 743.00, 767.00, 779.00, 779.00, 803.00, 803.00,
815.00, 815.00, 826.00, 826.00, 838.00, 850.00, 862.00, 862.00, 886.00,
886.00, 898.00, 898.00, 910.00, 910.00, 946.00, 946.00, 970.00, 970.00,
982.00, 982.00, 994.00, 994.00, 970.00, 970.00, 958.00, 958.00, 970.00,
970.00, 1006.00, 1066.00, 1090.00, 1090.00, 1102.00, 1102.00, 1090.00,
1090.00, 1078.00, 1054.00, 1042.00, 1042.00, 1030.00, 1030.00, 1018.00,
1018.00, 1042.00, 1066.00, 1078.00, 1090.00, 1162.00, 1162.00, 1174.00,
1197.00, 1221.00, 1221.00, 1209.00, 1209.00, 1221.00, 1245.00, 1269.00,
1293.00, 1329.00, 1341.00, 1353.00, 1353.00, 1341.00, 1341.00, 1329.00,
1329.00, 1317.00, 1317.00, 1329.00, 1329.00, 1341.00, 1341.00, 1353.00,
1365.00, 1377.00, 1377.00, 1389.00, 1401.00, 1425.00, 1449.00, 1461.00,
1461.00, 1473.00, 1473.00, 1485.00, 1485.00, 1497.00, 1497.00, 1521.00,
1532.00, 1568.00, 1616.00, 1628.00, 1640.00, 1652.00, 1676.00, 1700.00,
1712.00, 1712.00, 1736.00, 1748.00, 1760.00, 1760.00, 1772.00, 1772.00,
1784.00, 1784.00, 1808.00, 1808.00, 1832.00, 1832.00, 1808.00, 1808.00,
1796.00, 1796.00, 1784.00, 1784.00, 1796.00, 1796.00, 1820.00, 1868.00,
1879.00, 1903.00, 1915.00, 1999.00, 2023.00, 2131.00, 2167.00, 2167.00,
2155.00, 2155.00, 2167.00, 2167.00, 2179.00, 2179.00, 2191.00, 2191.00,
2215.00, 2215.00, 2226.00, 2226.00, 2274.00, 2298.00, 2322.00, 2334.00,
2346.00, 2358.00, 2370.00, 2382.00, 2406.00, 2418.00, 2430.00, 2430.00,
2442.00, 2466.00, 2490.00, 2502.00, 2574.00, 2597.00, 2609.00, 2609.00,
2621.00, 2621.00, 2574.00, 2574.00, 2562.00, 2562.00, 2550.00, 2550.00,
2502.00, 2430.00, 2418.00, 2406.00, 2394.00, 2370.00, 2322.00, 2322.00,
2346.00, 2346.00, 2358.00, 2382.00, 2394.00, 2394.00, 2406.00, 2418.00,
2442.00, 2502.00, 2514.00, 2526.00, 2538.00, 2550.00, 2585.00, 2585.00,
2633.00, 2645.00, 2657.00, 2669.00, 2693.00, 2705.00, 2753.00, 2765.00,
2813.00, 2801.00, 2801.00, 2777.00, 2765.00, 2705.00, 2705.00, 2693.00,
2681.00, 2657.00, 2633.00, 2621.00, 2621.00, 2574.00), y=c(0.00, 4189.00,
4204.00, 4219.00, 4219.00, 4233.00, 4233.00, 4248.00, 4248.00, 4233.00,
4233.00, 4204.00, 4204.00, 4174.00, 4174.00, 4130.00, 4130.00, 4115.00,
4085.00, 4056.00, 4041.00, 4011.00, 3996.00, 3981.00, 3981.00, 3967.00,
3967.00, 3937.00, 3922.00, 3789.00, 3774.00, 3744.00, 3730.00, 3641.00,
3626.00, 3611.00, 3596.00, 3537.00, 3507.00, 3478.00, 3478.00, 3433.00,
3433.00, 3389.00, 3389.00, 3374.00, 3359.00, 3241.00, 3226.00, 3211.00,
3093.00, 3078.00, 3078.00, 3063.00, 3033.00, 3019.00, 2989.00, 2930.00,
2915.00, 2870.00, 2856.00, 2826.00, 2796.00, 2796.00, 2767.00, 2693.00,
2678.00, 2663.00, 2648.00, 2619.00, 2604.00, 2574.00, 2515.00, 2485.00,
2485.00, 2456.00, 2441.00, 2426.00, 2411.00, 2396.00, 2396.00, 2381.00,
2367.00, 2322.00, 2307.00, 2293.00, 2263.00, 2204.00, 2204.00, 2189.00,
2189.00, 2174.00, 2115.00, 2100.00, 2100.00, 2070.00, 2070.00, 2011.00,
1996.00, 1937.00, 1922.00, 1863.00, 1863.00, 1789.00, 1789.00, 1774.00,
1774.00, 1789.00, 1789.00, 1774.00, 1774.00, 1730.00, 1730.00, 1685.00,
1670.00, 1656.00, 1626.00, 1567.00, 1567.00, 1537.00, 1537.00, 1507.00,
1507.00, 1493.00, 1493.00, 1463.00, 1463.00, 1448.00, 1448.00, 1433.00,
1419.00, 1389.00, 1374.00, 1344.00, 1315.00, 1285.00, 1285.00, 1270.00,
1270.00, 1256.00, 1256.00, 1241.00, 1226.00, 1196.00, 1181.00, 1137.00,
1122.00, 1122.00, 1093.00, 1093.00, 1063.00, 1063.00, 1048.00, 1033.00,
1019.00, 1019.00, 1004.00, 974.00, 944.00, 870.00, 856.00, 841.00, 841.00,
826.00, 811.00, 752.00, 752.00, 781.00, 796.00, 811.00, 826.00, 841.00,
930.00, 944.00, 959.00, 959.00, 974.00, 989.00, 1019.00, 1033.00, 1048.00,
1078.00, 1093.00, 1107.00, 1122.00, 1122.00, 1137.00, 1152.00, 1181.00,
1196.00, 1211.00, 1359.00, 1374.00, 1389.00, 1433.00, 1463.00, 1493.00,
1522.00, 1537.00, 1581.00, 1596.00, 1656.00, 1685.00, 1700.00, 1715.00,
1759.00, 1774.00, 1789.00, 1833.00, 1833.00, 1804.00, 1789.00, 1774.00,
1744.00, 1730.00, 1715.00, 1700.00, 1700.00, 1685.00, 1656.00, 1641.00,
1611.00, 1596.00, 1507.00, 1478.00, 1478.00, 1463.00, 1463.00, 1552.00,
1581.00, 1596.00, 1596.00, 1567.00, 1507.00, 1493.00, 1419.00, 1404.00,
1404.00, 1433.00, 1404.00, 1404.00, 1419.00, 1404.00, 1315.00, 1300.00,
1256.00, 1241.00, 1211.00, 1196.00, 1137.00, 1122.00, 1048.00, 1033.00,
1019.00, 1004.00, 1004.00, 989.00, 974.00, 959.00, 959.00, 930.00,
930.00, 944.00, 1107.00, 1122.00, 1137.00, 1152.00, 1196.00, 1211.00,
1300.00, 1330.00, 1330.00, 1374.00, 1374.00, 1359.00, 1359.00, 1344.00,
1374.00, 1374.00, 1389.00, 1419.00, 1448.00, 1448.00, 1463.00, 1478.00,
1493.00, 1507.00, 1522.00, 1537.00, 1567.00, 1581.00, 1611.00, 1656.00,
1685.00, 1730.00, 1744.00, 1759.00, 1774.00, 1848.00, 1863.00, 1922.00,
1952.00, 1952.00, 1937.00, 1937.00, 1922.00, 1922.00, 1893.00, 1893.00,
1937.00, 2011.00, 2026.00, 2085.00, 2100.00, 2115.00, 2130.00, 2159.00,
2174.00, 2189.00, 2219.00, 2233.00, 2248.00, 2278.00, 2337.00, 2337.00,
2367.00, 2367.00, 2381.00, 2381.00, 2396.00, 2396.00, 2426.00, 2426.00,
2441.00, 2456.00, 2470.00, 2470.00, 2500.00, 2500.00, 2589.00, 2589.00,
2604.00, 2619.00, 2633.00, 2796.00, 2856.00, 2989.00, 3004.00, 3048.00,
3063.00, 3078.00, 3137.00, 3137.00, 3152.00, 3152.00, 3167.00, 3167.00,
3226.00, 3256.00, 3285.00, 3300.00, 3315.00, 3315.00, 3330.00, 3344.00,
3359.00, 3359.00, 3389.00, 3389.00, 3404.00, 3404.00, 3419.00, 3419.00,
3463.00, 3493.00, 3552.00, 3552.00, 3567.00, 3567.00, 3596.00, 3596.00,
3656.00, 3656.00, 3715.00, 3730.00, 3907.00, 3937.00, 3937.00, 4011.00,
4026.00, 4041.00, 4041.00, 4070.00, 4070.00, 4085.00, 4130.00, 4189.00)))

==> splancs_2.01-7.tar.gz: splancs/data/uganda.R <==
"uganda" <- list(x = c(2310.000000, 2298.000000, 2490.000000, 2346.000000,
2011.000000, 2310.000000, 2633.000000, 2609.000000, 2550.000000,
2609.000000, 2609.000000, 2262.000000, 2203.000000, 2286.000000,
2478.000000, 2203.000000, 1784.000000, 2107.000000, 2310.000000,
2358.000000, 2370.000000, 2023.000000, 2107.000000, 2215.000000,
2059.000000, 2011.000000, 2167.000000, 2179.000000, 2083.000000,
1987.000000, 1927.000000, 1868.000000, 1891.000000, 1987.000000,
2071.000000, 2059.000000, 1951.000000, 515.000000, 2322.000000,
2502.000000, 2358.000000, 2191.000000, 2047.000000, 1951.000000,
1903.000000, 1736.000000, 2753.000000, 2478.000000, 2131.000000,
1353.000000, 1724.000000, 1903.000000, 2023.000000, 2143.000000,
2322.000000, 2430.000000, 1293.000000, 1377.000000, 1413.000000,
1532.000000, 1616.000000, 1784.000000, 1856.000000, 1975.000000,
1509.000000, 1652.000000, 1820.000000, 1497.000000, 1604.000000,
1796.000000, 2143.000000, 2143.000000, 1293.000000, 1461.000000,
1521.000000, 1664.000000, 2071.000000, 1796.000000, 1712.000000,
1616.000000, 1592.000000, 1197.000000, 1353.000000, 1365.000000,
1174.000000, 1293.000000, 1377.000000, 1401.000000, 1449.000000,
1006.000000, 1066.000000, 1102.000000, 1138.000000, 1233.000000,
1209.000000, 1030.000000, 1078.000000, 1353.000000, 1544.000000,
1736.000000, 1688.000000, 1676.000000, 1401.000000, 1042.000000,
1090.000000, 1090.000000, 1078.000000, 1126.000000, 1162.000000,
862.000000, 683.000000, 611.000000, 587.000000, 515.000000, 432.000000,
324.000000, 731.000000, 695.000000, 635.000000, 563.000000 ), y =
c(4144.000000, 4070.000000, 3967.000000, 3878.000000, 3759.000000,
3804.000000, 3922.000000, 3804.000000, 3700.000000, 3715.000000,
3626.000000, 3656.000000, 3611.000000, 3581.000000, 3537.000000,
3493.000000, 3478.000000, 3419.000000, 3404.000000, 3404.000000,
3463.000000, 3389.000000, 3315.000000, 3300.000000, 3256.000000,
3196.000000, 3226.000000, 3152.000000, 3137.000000, 3107.000000,
3107.000000, 3122.000000, 3019.000000, 3019.000000, 3004.000000,
2944.000000, 2944.000000, 974.000000, 3078.000000, 3004.000000,
2930.000000, 2826.000000, 2796.000000, 2781.000000, 2856.000000,
2856.000000, 3759.000000, 3419.000000, 3048.000000, 2767.000000,
2648.000000, 2619.000000, 2678.000000, 2678.000000, 2722.000000,
2737.000000, 2559.000000, 2589.000000, 2633.000000, 2589.000000,
2604.000000, 2544.000000, 2544.000000, 2574.000000, 2441.000000,
2470.000000, 2426.000000, 2367.000000, 2322.000000, 2307.000000,
2322.000000, 2204.000000, 2248.000000, 2204.000000, 2204.000000,
2189.000000, 1967.000000, 2011.000000, 1981.000000, 2041.000000,
2159.000000, 2219.000000, 2174.000000, 2100.000000, 2100.000000,
2026.000000, 2011.000000, 1922.000000, 1907.000000, 1937.000000,
1937.000000, 1922.000000, 1893.000000, 1848.000000, 1937.000000,
2056.000000, 2011.000000, 1848.000000, 1670.000000, 1656.000000,
1537.000000, 1478.000000, 1419.000000, 1522.000000, 1537.000000,
1581.000000, 1641.000000, 1730.000000, 1685.000000, 1641.000000,
1670.000000, 1611.000000, 1730.000000, 1700.000000, 1685.000000,
1700.000000, 1211.000000, 1093.000000, 974.000000, 1004.000000),
area=c(xl=324, xu=2753, yl=974, yu=4144), poly=cbind(x=c(2574.00,
2574.00, 2562.00, 2526.00, 2514.00, 2346.00, 2334.00, 2322.00, 2310.00,
2298.00, 2274.00, 2250.00, 2226.00, 2215.00, 2179.00, 2155.00, 2143.00,
2143.00, 2119.00, 2119.00, 2095.00, 2095.00, 2083.00, 2071.00, 2059.00,
2047.00, 2023.00, 2023.00, 1915.00, 1915.00, 1891.00, 1891.00, 1820.00,
1820.00, 1808.00, 1808.00, 1760.00, 1760.00, 1736.00, 1700.00, 1664.00,
1652.00, 1616.00, 1604.00, 1592.00, 1592.00, 1497.00, 1497.00, 1485.00,
1485.00, 1473.00, 1389.00, 1377.00, 1377.00, 1365.00, 1365.00, 1317.00,
1329.00, 1329.00, 1341.00, 1341.00, 1317.00, 1305.00, 1281.00, 1281.00,
1269.00, 1269.00, 1257.00, 1281.00, 1281.00, 1257.00, 1257.00, 1233.00,
1221.00, 1197.00, 1197.00, 1185.00, 1185.00, 1174.00, 1150.00, 1138.00,
1138.00, 1102.00, 1102.00, 1090.00, 1090.00, 1042.00, 1030.00, 1018.00,
1006.00, 994.00, 994.00, 982.00, 970.00, 946.00, 922.00, 874.00, 874.00,
826.00, 826.00, 779.00, 755.00, 695.00, 683.00, 671.00, 527.00, 515.00,
372.00, 360.00, 348.00, 312.00, 300.00, 264.00, 264.00, 276.00, 276.00,
324.00, 384.00, 408.00, 491.00, 515.00, 527.00, 539.00, 587.00, 611.00,
635.00, 647.00, 695.00, 707.00, 707.00, 731.00, 731.00, 755.00, 755.00,
731.00, 719.00, 707.00, 695.00, 683.00, 671.00, 659.00, 659.00, 635.00,
647.00, 647.00, 635.00, 623.00, 599.00, 575.00, 551.00, 539.00, 527.00,
527.00, 515.00, 503.00, 491.00, 491.00, 468.00, 527.00, 527.00, 539.00,
551.00, 563.00, 563.00, 611.00, 659.00, 683.00, 683.00, 671.00, 671.00,
659.00, 731.00, 731.00, 743.00, 767.00, 779.00, 779.00, 803.00, 803.00,
815.00, 815.00, 826.00, 826.00, 838.00, 850.00, 862.00, 862.00, 886.00,
886.00, 898.00, 898.00, 910.00, 910.00, 946.00, 946.00, 970.00, 970.00,
982.00, 982.00, 994.00, 994.00, 970.00, 970.00, 958.00, 958.00, 970.00,
970.00, 1006.00, 1066.00, 1090.00, 1090.00, 1102.00, 1102.00, 1090.00,
1090.00, 1078.00, 1054.00, 1042.00, 1042.00, 1030.00, 1030.00, 1018.00,
1018.00, 1042.00, 1066.00, 1078.00, 1090.00, 1162.00, 1162.00, 1174.00,
1197.00, 1221.00, 1221.00, 1209.00, 1209.00, 1221.00, 1245.00, 1269.00,
1293.00, 1329.00, 1341.00, 1353.00, 1353.00, 1341.00, 1341.00, 1329.00,
1329.00, 1317.00, 1317.00, 1329.00, 1329.00, 1341.00, 1341.00, 1353.00,
1365.00, 1377.00, 1377.00, 1389.00, 1401.00, 1425.00, 1449.00, 1461.00,
1461.00, 1473.00, 1473.00, 1485.00, 1485.00, 1497.00, 1497.00, 1521.00,
1532.00, 1568.00, 1616.00, 1628.00, 1640.00, 1652.00, 1676.00, 1700.00,
1712.00, 1712.00, 1736.00, 1748.00, 1760.00, 1760.00, 1772.00, 1772.00,
1784.00, 1784.00, 1808.00, 1808.00, 1832.00, 1832.00, 1808.00, 1808.00,
1796.00, 1796.00, 1784.00, 1784.00, 1796.00, 1796.00, 1820.00, 1868.00,
1879.00, 1903.00, 1915.00, 1999.00, 2023.00, 2131.00, 2167.00, 2167.00,
2155.00, 2155.00, 2167.00, 2167.00, 2179.00, 2179.00, 2191.00, 2191.00,
2215.00, 2215.00, 2226.00, 2226.00, 2274.00, 2298.00, 2322.00, 2334.00,
2346.00, 2358.00, 2370.00, 2382.00, 2406.00, 2418.00, 2430.00, 2430.00,
2442.00, 2466.00, 2490.00, 2502.00, 2574.00, 2597.00, 2609.00, 2609.00,
2621.00, 2621.00, 2574.00, 2574.00, 2562.00, 2562.00, 2550.00, 2550.00,
2502.00, 2430.00, 2418.00, 2406.00, 2394.00, 2370.00, 2322.00, 2322.00,
2346.00, 2346.00, 2358.00, 2382.00, 2394.00, 2394.00, 2406.00, 2418.00,
2442.00, 2502.00, 2514.00, 2526.00, 2538.00, 2550.00, 2585.00, 2585.00,
2633.00, 2645.00, 2657.00, 2669.00, 2693.00, 2705.00, 2753.00, 2765.00,
2813.00, 2801.00, 2801.00, 2777.00, 2765.00, 2705.00, 2705.00, 2693.00,
2681.00, 2657.00, 2633.00, 2621.00, 2621.00, 2574.00), y=c(4189.00,
4204.00, 4219.00, 4219.00, 4233.00, 4233.00, 4248.00, 4248.00, 4233.00,
4233.00, 4204.00, 4204.00, 4174.00, 4174.00, 4130.00, 4130.00, 4115.00,
4085.00, 4056.00, 4041.00, 4011.00, 3996.00, 3981.00, 3981.00, 3967.00,
3967.00, 3937.00, 3922.00, 3789.00, 3774.00, 3744.00, 3730.00, 3641.00,
3626.00, 3611.00, 3596.00, 3537.00, 3507.00, 3478.00, 3478.00, 3433.00,
3433.00, 3389.00, 3389.00, 3374.00, 3359.00, 3241.00, 3226.00, 3211.00,
3093.00, 3078.00, 3078.00, 3063.00, 3033.00, 3019.00, 2989.00, 2930.00,
2915.00, 2870.00, 2856.00, 2826.00, 2796.00, 2796.00, 2767.00, 2693.00,
2678.00, 2663.00, 2648.00, 2619.00, 2604.00, 2574.00, 2515.00, 2485.00,
2485.00, 2456.00, 2441.00, 2426.00, 2411.00, 2396.00, 2396.00, 2381.00,
2367.00, 2322.00, 2307.00, 2293.00, 2263.00, 2204.00, 2204.00, 2189.00,
2189.00, 2174.00, 2115.00, 2100.00, 2100.00, 2070.00, 2070.00, 2011.00,
1996.00, 1937.00, 1922.00, 1863.00, 1863.00, 1789.00, 1789.00, 1774.00,
1774.00, 1789.00, 1789.00, 1774.00, 1774.00, 1730.00, 1730.00, 1685.00,
1670.00, 1656.00, 1626.00, 1567.00, 1567.00, 1537.00, 1537.00, 1507.00,
1507.00, 1493.00, 1493.00, 1463.00, 1463.00, 1448.00, 1448.00, 1433.00,
1419.00, 1389.00, 1374.00, 1344.00, 1315.00, 1285.00, 1285.00, 1270.00,
1270.00, 1256.00, 1256.00, 1241.00, 1226.00, 1196.00, 1181.00, 1137.00,
1122.00, 1122.00, 1093.00, 1093.00, 1063.00, 1063.00, 1048.00, 1033.00,
1019.00, 1019.00, 1004.00, 974.00, 944.00, 870.00, 856.00, 841.00, 841.00,
826.00, 811.00, 752.00, 752.00, 781.00, 796.00, 811.00, 826.00, 841.00,
930.00, 944.00, 959.00, 959.00, 974.00, 989.00, 1019.00, 1033.00, 1048.00,
1078.00, 1093.00, 1107.00, 1122.00, 1122.00, 1137.00, 1152.00, 1181.00,
1196.00, 1211.00, 1359.00, 1374.00, 1389.00, 1433.00, 1463.00, 1493.00,
1522.00, 1537.00, 1581.00, 1596.00, 1656.00, 1685.00, 1700.00, 1715.00,
1759.00, 1774.00, 1789.00, 1833.00, 1833.00, 1804.00, 1789.00, 1774.00,
1744.00, 1730.00, 1715.00, 1700.00, 1700.00, 1685.00, 1656.00, 1641.00,
1611.00, 1596.00, 1507.00, 1478.00, 1478.00, 1463.00, 1463.00, 1552.00,
1581.00, 1596.00, 1596.00, 1567.00, 1507.00, 1493.00, 1419.00, 1404.00,
1404.00, 1433.00, 1404.00, 1404.00, 1419.00, 1404.00, 1315.00, 1300.00,
1256.00, 1241.00, 1211.00, 1196.00, 1137.00, 1122.00, 1048.00, 1033.00,
1019.00, 1004.00, 1004.00, 989.00, 974.00, 959.00, 959.00, 930.00,
930.00, 944.00, 1107.00, 1122.00, 1137.00, 1152.00, 1196.00, 1211.00,
1300.00, 1330.00, 1330.00, 1374.00, 1374.00, 1359.00, 1359.00, 1344.00,
1374.00, 1374.00, 1389.00, 1419.00, 1448.00, 1448.00, 1463.00, 1478.00,
1493.00, 1507.00, 1522.00, 1537.00, 1567.00, 1581.00, 1611.00, 1656.00,
1685.00, 1730.00, 1744.00, 1759.00, 1774.00, 1848.00, 1863.00, 1922.00,
1952.00, 1952.00, 1937.00, 1937.00, 1922.00, 1922.00, 1893.00, 1893.00,
1937.00, 2011.00, 2026.00, 2085.00, 2100.00, 2115.00, 2130.00, 2159.00,
2174.00, 2189.00, 2219.00, 2233.00, 2248.00, 2278.00, 2337.00, 2337.00,
2367.00, 2367.00, 2381.00, 2381.00, 2396.00, 2396.00, 2426.00, 2426.00,
2441.00, 2456.00, 2470.00, 2470.00, 2500.00, 2500.00, 2589.00, 2589.00,
2604.00, 2619.00, 2633.00, 2796.00, 2856.00, 2989.00, 3004.00, 3048.00,
3063.00, 3078.00, 3137.00, 3137.00, 3152.00, 3152.00, 3167.00, 3167.00,
3226.00, 3256.00, 3285.00, 3300.00, 3315.00, 3315.00, 3330.00, 3344.00,
3359.00, 3359.00, 3389.00, 3389.00, 3404.00, 3404.00, 3419.00, 3419.00,
3463.00, 3493.00, 3552.00, 3552.00, 3567.00, 3567.00, 3596.00, 3596.00,
3656.00, 3656.00, 3715.00, 3730.00, 3907.00, 3937.00, 3937.00, 4011.00,
4026.00, 4041.00, 4041.00, 4070.00, 4070.00, 4085.00, 4130.00, 4189.00)))
